@@ -38,6 +38,11 @@ metadata_creators_affiliations_id = TermsFacet(
 )
 
 
+metadata_creators_affiliations_type = TermsFacet(
+    field="metadata.creators.affiliations.type"
+)
+
+
 metadata_creators_affiliations_hierarchy_parent = TermsFacet(
     field="metadata.creators.affiliations.hierarchy.parent"
 )
@@ -77,6 +82,9 @@ metadata_creators_authorityIdentifiers_scheme = TermsFacet(
 metadata_contributors_role_id = TermsFacet(field="metadata.contributors.role.id")
 
 
+metadata_contributors_role_type = TermsFacet(field="metadata.contributors.role.type")
+
+
 metadata_contributors_role__version = TermsFacet(field="metadata.contributors.role.@v")
 
 
@@ -85,6 +93,11 @@ metadata_contributors_affiliations_id = TermsFacet(
 )
 
 
+metadata_contributors_affiliations_type = TermsFacet(
+    field="metadata.contributors.affiliations.type"
+)
+
+
 metadata_contributors_affiliations_hierarchy_parent = TermsFacet(
     field="metadata.contributors.affiliations.hierarchy.parent"
 )
@@ -124,6 +137,9 @@ metadata_contributors_authorityIdentifiers_scheme = TermsFacet(
 metadata_resourceType_id = TermsFacet(field="metadata.resourceType.id")
 
 
+metadata_resourceType_type = TermsFacet(field="metadata.resourceType.type")
+
+
 metadata_resourceType__version = TermsFacet(field="metadata.resourceType.@v")
 
 
@@ -165,12 +181,18 @@ metadata_subjects_classificationCode = TermsFacet(
 metadata_subjectCategories_id = TermsFacet(field="metadata.subjectCategories.id")
 
 
+metadata_subjectCategories_type = TermsFacet(field="metadata.subjectCategories.type")
+
+
 metadata_subjectCategories__version = TermsFacet(field="metadata.subjectCategories.@v")
 
 
 metadata_languages_id = TermsFacet(field="metadata.languages.id")
 
 
+metadata_languages_type = TermsFacet(field="metadata.languages.type")
+
+
 metadata_languages__version = TermsFacet(field="metadata.languages.@v")
 
 
@@ -229,12 +251,18 @@ metadata_technicalInfo_value_keyword = NestedLabeledFacet(
 metadata_rights_id = TermsFacet(field="metadata.rights.id")
 
 
+metadata_rights_type = TermsFacet(field="metadata.rights.type")
+
+
 metadata_rights__version = TermsFacet(field="metadata.rights.@v")
 
 
 metadata_accessRights_id = TermsFacet(field="metadata.accessRights.id")
 
 
+metadata_accessRights_type = TermsFacet(field="metadata.accessRights.type")
+
+
 metadata_accessRights__version = TermsFacet(field="metadata.accessRights.@v")
 
 
@@ -243,6 +271,11 @@ metadata_relatedItems_itemCreators_affiliations_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemCreators_affiliations_type = TermsFacet(
+    field="metadata.relatedItems.itemCreators.affiliations.type"
+)
+
+
 metadata_relatedItems_itemCreators_affiliations_hierarchy_parent = TermsFacet(
     field="metadata.relatedItems.itemCreators.affiliations.hierarchy.parent"
 )
@@ -288,6 +321,11 @@ metadata_relatedItems_itemContributors_role_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemContributors_role_type = TermsFacet(
+    field="metadata.relatedItems.itemContributors.role.type"
+)
+
+
 metadata_relatedItems_itemContributors_role__version = TermsFacet(
     field="metadata.relatedItems.itemContributors.role.@v"
 )
@@ -298,6 +336,11 @@ metadata_relatedItems_itemContributors_affiliations_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemContributors_affiliations_type = TermsFacet(
+    field="metadata.relatedItems.itemContributors.affiliations.type"
+)
+
+
 metadata_relatedItems_itemContributors_affiliations_hierarchy_parent = TermsFacet(
     field="metadata.relatedItems.itemContributors.affiliations.hierarchy.parent"
 )
@@ -380,6 +423,11 @@ metadata_relatedItems_itemRelationType_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemRelationType_type = TermsFacet(
+    field="metadata.relatedItems.itemRelationType.type"
+)
+
+
 metadata_relatedItems_itemRelationType__version = TermsFacet(
     field="metadata.relatedItems.itemRelationType.@v"
 )
@@ -390,6 +438,11 @@ metadata_relatedItems_itemResourceType_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemResourceType_type = TermsFacet(
+    field="metadata.relatedItems.itemResourceType.type"
+)
+
+
 metadata_relatedItems_itemResourceType__version = TermsFacet(
     field="metadata.relatedItems.itemResourceType.@v"
 )
@@ -405,6 +458,11 @@ metadata_fundingReferences_funder_id = TermsFacet(
 )
 
 
+metadata_fundingReferences_funder_type = TermsFacet(
+    field="metadata.fundingReferences.funder.type"
+)
+
+
 metadata_fundingReferences_funder__version = TermsFacet(
     field="metadata.fundingReferences.funder.@v"
 )
@@ -493,6 +551,11 @@ metadata_events_eventLocation_country_id = TermsFacet(
 )
 
 
+metadata_events_eventLocation_country_type = TermsFacet(
+    field="metadata.events.eventLocation.country.type"
+)
+
+
 metadata_events_eventLocation_country__version = TermsFacet(
     field="metadata.events.eventLocation.country.@v"
 )
