@@ -1,6 +1,10 @@
 import marshmallow as ma
 from marshmallow import fields as ma_fields
-from oarepo_runtime.i18n.ui_schema import I18nStrUIField, MultilingualUIField
+from oarepo_runtime.i18n.ui_schema import (
+    I18nStrUIField,
+    MultilingualLocalizedUIField,
+    MultilingualUIField,
+)
 from oarepo_runtime.ui import marshmallow as l10n
 from oarepo_vocabularies.services.ui_schemas import HierarchyUISchema, I18nStrUIField
 
@@ -32,6 +36,7 @@ class NRDegreeGrantorUISchema(ma.Schema):
 
     _id = ma_fields.String(data_key="id", attribute="id")
     title = I18nStrUIField()
+    type = ma_fields.String()
     hierarchy = ma_fields.Nested(lambda: HierarchyUISchema())
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -77,7 +82,7 @@ class NRDocumentMetadataUISchema(ma.Schema):
     )
     version = ma_fields.String()
     geoLocations = ma_fields.List(ma_fields.Nested(lambda: NRGeoLocationUISchema()))
-    accessibility = MultilingualUIField(I18nStrUIField())
+    accessibility = MultilingualLocalizedUIField(I18nStrUIField())
     series = ma_fields.List(ma_fields.Nested(lambda: NRSeriesUISchema()))
     externalLocation = ma_fields.Nested(lambda: NRExternalLocationUISchema())
     originalRecord = ma_fields.String()
@@ -90,7 +95,7 @@ class NRDocumentMetadataUISchema(ma.Schema):
     events = ma_fields.List(ma_fields.Nested(lambda: NREventUISchema()))
 
 
-class NRDocumentRecordUISchema(ma.Schema):
+class NRDocumentRecordUISchema(InvenioUISchema):
     """NRDocumentRecordUISchema schema."""
 
     metadata = ma_fields.Nested(lambda: NRDocumentMetadataUISchema())
